label - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- Label
- Label.font

# Label

Label(value) -> Label widget

Basic widget for simply displaying some text. Not really much to it, you can pass it a value which it will display.

## Label.font

Label.font -> pygame.Font

The font that this label is using.